@@ -7,6 +7,7 @@ describe 'murano' do
 
   let :params do {
     :admin_password => 'secrete',
+    :purge_config   => false,
   }
   end
 
@@ -19,6 +20,12 @@ describe 'murano' do
       :ensure => 'present'
     }) }
 
+    it 'passes purge to resource' do
+      is_expected.to contain_resources('murano_config').with({
+        :purge => false
+      })
+    end
+
     it { is_expected.to contain_class('mysql::bindings::python') }
 
     it { is_expected.to contain_murano_config('oslo_messaging_notifications/driver').with_value('messagingv2') }
